@@ -6,9 +6,9 @@
   if(interactive())
   {
     meta <- packageDescription("circular")
-    packageStartupMessage(
-         "Package 'circular', ", meta$Version, " (", meta$Date, "). ",
-         "Type 'help(Circular)' for summary information. \n Please report any bug or comments to Claudio Agostinelli <claudio.agostinelli@unitn.it>")
+    # packageStartupMessage(
+    #      "Package 'circular', ", meta$Version, " (", meta$Date, "). ",
+    #      "Type 'help(Circular)' for summary information.")
   }
   invisible()
 }
